 /*
  * resultscreen.c - Dictionary Result Screen Functions
  * Copyright (c)2004 Pawel Szymczykowski <pawel@makenai.net>
  *
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
  * It is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with Foobar; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */

#include "resultscreen.h"

extern GPDRAWSURFACE gpDraw[2];
extern BitFont * hankaku;
extern BitFont * zenkaku;
extern JConsole * console;
extern Jiten * dictionary;
extern int currentSurface;

void resultScreen(char * term)
{
	char ch;
	int i=0, init = TRUE;
	char definition[1024];

	SetClockSpeed(CLOCK133);

	console->clear();
	if (dictionary->search(term) == 0)
	{
		while ((init || (dictionary->next() == 0)) && i < MAX_RESULTS) 
		{
			dictionary->get_record(definition);
			console->print(definition);
			if (console->get_cur_line_length() == console->get_num_cols()) console->print("\n");
			else console->print("\n\n"); 
			// It's likely that the above if doesn't work correctly in all cases.
			// Also, removing newlines will often corrupt display. maybe JConsole problem..
			init = FALSE;
			i++;
		}
	} else {
		console->print("No entries found.\n");
	};
	
	SetClockSpeed(CLOCK40);
	
	init = TRUE;	
	currentSurface = !currentSurface;
	while (1)
	{
		if (!init)
		{
			ch = GpKeyGet();
			if (!GpKeyChanged()) continue;

			switch(ch)
			{
				case GPC_VK_UP:
					console->scroll_up();
				break;
				case GPC_VK_DOWN:
					console->scroll_dn();
				break;
				case GPC_VK_FR:
					for (i=0;i<console->get_num_rows();i++)
						console->scroll_dn();
				break;
				case GPC_VK_FL:
					for (i=0;i<console->get_num_rows();i++)
						console->scroll_up();
				break;
				case GPC_VK_FA | GPC_VK_FL:
					console->home();
				break;
				case GPC_VK_FA | GPC_VK_FR:
					console->end();
				break;
				case GPC_VK_FB:
					return;
				break;
			}
		}
		init = FALSE;

		GpRectFill(NULL, &gpDraw[currentSurface], 0, 0, LCD_WIDTH, LCD_HEIGHT, 0xFF);
		GpRectDraw(&gpDraw[currentSurface], 10, 10, 309, 229, 0x00);
		putxbm(&gpDraw[currentSurface], 300, 10, scrollbar_bits, scrollbar_width, scrollbar_height, 0x00);
		draw_scrollbar_pos(console->get_top_line(), console->get_num_lines(), console->get_num_rows());
		console->draw(&gpDraw[currentSurface]);
		GpSurfaceFlip(&gpDraw[currentSurface]);
		currentSurface = !currentSurface;
	}
}

void draw_scrollbar_pos(int top, int lines, int rows)
{
	int x1 = SCROLLBAR_X - 1;
	int y1 = SCROLLBAR_Y + 10 + (top * SCROLLBAR_SIZE / lines);
	int x2 = SCROLLBAR_X + 10;
	int y2 = y1 + ((rows >= lines) ? (SCROLLBAR_SIZE - 1) : (rows * SCROLLBAR_SIZE / lines));

	GpRectFill(NULL, &gpDraw[currentSurface], x1, y1, x2 - x1, y2 - y1, 0xFF);
	GpRectDraw(&gpDraw[currentSurface], x1, y1, x2, y2, 0x00);
}
